@@ -10,33 +10,33 @@
 #include <math.h>
 
 void gcmp2 (int *pop12,
-            int *pop21, 
-            int *nk, 
-            int *K, 
-            int *n1, 
-            int *n2, 
-            int *n0, 
+            int *pop21,
+            int *nk,
+            int *K,
+            int *n1,
+            int *n2,
+            int *n0,
             int *samplesize, int *burnin, int *interval,
-            double *mu, double *kappa, 
-            double *sigma,  double *df,
-	    int *Npi,
-            double *muproposal, 
-            double *sigmaproposal, 
-            int *N, int *maxN, 
-            double *sample, 
-            double *ppos, 
-            double *lpriorm, 
+            double *mu, double *dfmu,
+            double *sigma, double *dfsigma,
+            double *lnlam, double *nu,
+            int *Npi,
+            double *muproposal,
+            double *nuproposal,
+            int *N, int *maxN,
+            double *sample,
+            double *posu,
+            double *lpriorm,
             int *burnintheta,
-	    int *verbose
-			 ) {
+            int *verbose
+            ) {
   int dimsample, Np;
   int step, staken, getone=1, intervalone=1, verboseMHcmp = 0;
   int i, ni, Ni, Ki, isamp, iinterval, isamplesize, iburnin;
-  int ni1, ni2, ni0;
-  double mui, sigmai, dsamp;
-  double dkappa, ddf, dmu, dsigma, dmuproposal, dsigmaproposal;
+  int ni1, ni2, ni0, unrecap;
+  double mui, sigmai, lnlami, nui, dsamp, sigma2i;
+  double ddfmu, ddfsigma, dnuproposal;
   int tU1, tU2, sizei, imaxN, imaxm, give_log0=0, give_log1=1;
-  int maxpop;
   double r1, r2, gammart, pis, Nd;
   double temp;
   double errval=0.0000000001, lzcmp;
@@ -49,25 +49,21 @@ void gcmp2 (int *pop12,
   Ni=(*N);
   Ki=(*K);
   imaxN=(*maxN);
-  ni = ni1 + ni2 - ni0;
+  ni = ni1 + ni2 - ni0; /* The number unique people seen */
   imaxm=imaxN-ni;
   isamplesize=(*samplesize);
   iinterval=(*interval);
   iburnin=(*burnin);
   Np=(*Npi);
-  dkappa=(*kappa);
-  ddf=(*df);
-  dsigma=(*sigma);
-  dmu=(*mu);
-  dsigmaproposal=(*sigmaproposal);
-  dmuproposal=(*muproposal);
+  ddfmu=(*dfmu);
+  ddfsigma=(*dfsigma);
+  dnuproposal=(*nuproposal);
 
   dimsample=5+Np;
 
   double *pi = (double *) malloc(sizeof(double) * Ki);
-  double *pd = (double *) malloc(sizeof(double) * Ki);
-  int *d1 = (int *) malloc(sizeof(int) * ni1);
-  int *d2 = (int *) malloc(sizeof(int) * (ni2+1));
+  int *d1 = (int *) malloc(sizeof(int) * imaxN);
+  int *d2 = (int *) malloc(sizeof(int) * imaxN);
   int *b1 = (int *) malloc(sizeof(int) * ni1);
   int *b2 = (int *) malloc(sizeof(int) * (ni2+1));
   int *Nk = (int *) malloc(sizeof(int) * Ki);
@@ -75,23 +71,27 @@ void gcmp2 (int *pop12,
   double *lpm = (double *) malloc(sizeof(double) * imaxm);
   double *pdegi = (double *) malloc(sizeof(double) * (Np+1));
   double *psample = (double *) malloc(sizeof(double) * (Np+1));
-  double *musample = (double *) malloc(sizeof(double));
-  double *sigmasample = (double *) malloc(sizeof(double));
+  double *lnlamsample = (double *) malloc(sizeof(double));
+  double *nusample = (double *) malloc(sizeof(double));
 
-  maxpop=0;
-  for (i=0; i<ni1; i++){
-    if((pop12[i]>0) && (pop12[i] <= Ki)){ d1[i]=pop12[i];}
-    if(pop12[i]==0){ d1[i]=1;}
-    if(pop12[i]>Ki){ d1[i]=Ki;}
-    if(pop12[i]>maxpop){maxpop=pop12[i];}
+  for (i=0; i<Ki; i++){
+    nk[i]=0;
+  }
+  unrecap=0;
+  for (i=0; i<ni; i++){
+    if((pop12[i] >0) && (pop12[i] <= Ki)){ d1[i]=pop12[i];}
+    if( pop12[i]==0){ d1[i]=1;}
+    if( pop12[i]>Ki){ d1[i]=Ki;}
+    nk[d1[i]-1]=nk[d1[i]-1]+1;
+    unrecap+=d1[i];
   }
-  d2[ni2] = 0;
   for (i=0; i<ni2; i++){
-    if((pop21[i]>0) && (pop21[i] <= Ki)){ d2[i]=pop21[i];}
-    if(pop21[i]==0){ d2[i]=1;}
-    if(pop21[i]>Ki){ d2[i]=Ki;}
-    if(pop21[i]>maxpop){maxpop=pop21[i];}
+    if((pop21[i] >0) && (pop21[i] <= Ki)){ d2[i]=pop21[i];}
+    if( pop21[i]==0){ d2[i]=1;}
+    if( pop21[i]>Ki){ d2[i]=Ki;}
+    unrecap-=d2[i];
   }
+
   // b is the cumulative version of d, which is uobs
   // so b1 is cumulative unit sizes for first list
   // b2 is cumulative unit sizes for second list
@@ -100,7 +100,7 @@ void gcmp2 (int *pop12,
     b1[i]=b1[i+1]+d1[i];
   }
   b2[ni2]=0;
-  if(ni1 > 0){
+  if(ni2 > 0){
     b2[ni2-1]=d2[ni2-1];
     for (i=(ni2-2); i>=0; i--){
       b2[i]=b2[i+1]+d2[i];
@@ -109,16 +109,22 @@ void gcmp2 (int *pop12,
   for (i=0; i<Ki; i++){
      Nk[i]=nk[i];
      Nkpos[i]=0;
-     ppos[i]=0.;
+     posu[i]=0.;
+  }
+  for (i=ni1; i<imaxN; i++){
+    d1[i]=d1[(int)trunc(10*unif_rand()+ni1-10)];
   }
   // tU1 is the total unit sizes from the first list
   tU1=0;
   for (i=ni1; i<Ni; i++){
-    tU1+=pop12[i];
+    tU1+=d1[i];
   }
-  tU2=0;
+  for (i=ni2; i<imaxN; i++){
+    d2[i]=d2[(int)trunc(10*unif_rand()+ni2-10)];
+  }
+  tU2=unrecap;
   for (i=ni2; i<Ni; i++){
-    tU2+=pop21[i];
+    tU2+=d2[i];
   }
   /* Draw initial phis */
   r1=0.;
@@ -133,38 +139,38 @@ void gcmp2 (int *pop12,
   for (i=0; i<Np; i++){
      psample[i] = 0.01;
   }
-  musample[0] = dmu;
-  sigmasample[0] = dsigma;
+  lnlamsample[0] = (*lnlam);
+  nusample[0] = (*nu);
 
   isamp = 0;
   step = -iburnin;
   while (isamp < isamplesize) {
     /* Draw new theta */
     /* but less often than the other full conditionals */
-    if (step == -iburnin || step==(10*(step/10))) { 
-     MHcmptheta(Nk,K,mu,kappa,sigma,df,muproposal,sigmaproposal,
+    if (step == -iburnin || step==(10*(step/10))) {
+     MHcmptheta(Nk,K,mu,dfmu,sigma,dfsigma,muproposal,nuproposal,
            &Ni, &Np, psample,
-	   musample, sigmasample, &getone, &staken, burnintheta, &intervalone, 
-	   &verboseMHcmp);
+           lnlamsample, nusample, &getone, &staken, burnintheta, &intervalone,
+           &verboseMHcmp);
     }
 
     for (i=0; i<Np; i++){
       pdegi[i] = psample[i];
     }
-    mui=musample[0];
-    sigmai=sigmasample[0];
-//  if(sigmai > 4.0 || mui > 4.5) Rprintf("mui %f sigmai %f kappa %f\n", mui, sigmai, kappa);
+    lnlami=lnlamsample[0];
+    nui=nusample[0];
+//  if(nui > 4.0 || lnlami > 4.5) Rprintf("lnlami %f nui %f dfmu %f\n", lnlami, nui, dfmu);
 
     /* Draw new N */
 
     /* First find the degree distribution */
     pis=0.;
-    lzcmp = zcmp(exp(mui), sigmai, errval, Ki, give_log1);
+    lzcmp = zcmp(exp(lnlami), nui, errval, Ki, give_log1);
     if(lzcmp < -100000.0){continue;}
-    pi[Np]=cmp(Np+1,mui,sigmai,lzcmp,give_log0);
-//Rprintf("mui %f sigmai %f lzcmp %f pi %f\n", mui, sigmai, lzcmp, pi[Np]);
+    pi[Np]=cmp(Np+1,lnlami,nui,lzcmp,give_log0);
+//Rprintf("lnlami %f nui %f lzcmp %f pi %f\n", lnlami, nui, lzcmp, pi[Np]);
     for (i=Np+1; i<Ki; i++){
-      pi[i]=pi[i-1]*exp(mui-sigmai*log((double)(i+1)));
+      pi[i]=pi[i-1]*exp(lnlami-nui*log((double)(i+1)));
     }
 //  Rprintf("isamp %d pis %f\n", isamp, pis);
     pis=1.-exp(-lzcmp);
@@ -183,6 +189,18 @@ void gcmp2 (int *pop12,
     for (i=0; i<Np; i++){
       pi[i]=pdegi[i];
     }
+
+    // Now computes mean and s.d. from log-lambda and nu
+    mui=0.0;
+    sigma2i=0.0;
+    for (i=0; i<Ki; i++){
+      mui+=pi[i]*(i+1);
+      sigma2i+=pi[i]*(i+1)*(i+1);
+    }
+    sigma2i=sigma2i-mui*mui;
+    sigmai  = sqrt(sigma2i);
+
+
     gammart=0.;
     for (i=0; i<Ki; i++){
       gammart+=(exp(-(r1 + r2)*(i+1))*pi[i]);
@@ -210,16 +228,16 @@ void gcmp2 (int *pop12,
     // Add back the sample size
     Ni += ni;
     if(Ni > imaxN) Ni = imaxN;
-		    
+
     /* Draw phis */
     // tU1 is the total unit sizes from first list
     tU1=0;
     for (i=ni1; i<Ni; i++){
-      tU1+=pop12[i];
+      tU1+=d1[i];
     }
-    tU2=0;
+    tU2=unrecap;
     for (i=ni2; i<Ni; i++){
-      tU2+=pop21[i];
+      tU2+=d2[i];
     }
     r1=0.;
     for (i=0; i<ni1; i++){
@@ -248,8 +266,8 @@ void gcmp2 (int *pop12,
        while(log(1.0-unif_rand()) > -(r1+r2)*sizei){
         /* Now propose unseen size for unit i */
         /* In the next two lines a sizei is chosen */
-        /* with parameters mui and sigmai */
-	temp = unif_rand();
+        /* with parameters mui and nui */
+        temp = unif_rand();
 //      gammart = pi[Ki-1] * unif_rand();
         for (sizei=1; sizei<=Ki; sizei++){
           if(temp <= pi[sizei-1]) break;
@@ -258,12 +276,12 @@ void gcmp2 (int *pop12,
        }
       }
 //    if(sizei >= Ki){sizei=Ki-1;}
-      pop12[i]=sizei;
-      pop21[i]=sizei;
+      d1[i]=sizei;
+      d2[i]=sizei;
 //    if((sizei <= 0) | (sizei > Ki-1)) Rprintf("sizei %d r %f\n", sizei,r);
       Nk[sizei-1]=Nk[sizei-1]+1;
     }
-    if (step > 0 && step==(iinterval*(step/iinterval))) { 
+    if (step > 0 && step==(iinterval*(step/iinterval))) {
       /* record statistics for posterity */
       Nd=(double)Ni;
       sample[isamp*dimsample  ]=Nd;
@@ -282,7 +300,7 @@ void gcmp2 (int *pop12,
       }
       for (i=0; i<Ki; i++){
         Nkpos[i]=Nkpos[i]+Nk[i];
-        ppos[i]+=((Nk[i]*1.)/Nd);
+        posu[i]+=((Nk[i]*1.)/Nd);
       }
       isamp++;
       if (*verbose && isamplesize==(isamp*(isamplesize/isamp))) Rprintf("Taken %d samples...\n", isamp);
@@ -293,7 +311,7 @@ void gcmp2 (int *pop12,
   dsamp=((double)isamp);
   for (i=0; i<Ki; i++){
     nk[i]=Nkpos[i];
-    ppos[i]/=dsamp;
+    posu[i]/=dsamp;
   }
   for (i=0; i<ni1; i++){
      pop12[i]=d1[i];
@@ -303,7 +321,6 @@ void gcmp2 (int *pop12,
   }
   PutRNGstate();  /* Disable RNG before returning */
   free(pi);
-  free(pd);
   free(d1);
   free(d2);
   free(psample);
@@ -313,6 +330,6 @@ void gcmp2 (int *pop12,
   free(Nk);
   free(Nkpos);
   free(lpm);
-  free(musample);
-  free(sigmasample);
+  free(lnlamsample);
+  free(nusample);
 }
